@@ -35,35 +35,38 @@ def process(smpp_client, queue):
                     msisdns = document['json']['msisdn'].replace(' ', '')
                     msisdns = msisdns.split(',')
                     for index, msisdn in enumerate(msisdns):
-                        bar = {
-                            'message': document['json'].get(
-                                'message',
-                                'message vide'
-                                ),
-                            'msisdn': msisdn,
-                            'sender_id': document['json'].get(
-                                'sender_id',
-                                'bip'
-                                ),
-                            'encoding': document['json'].get(
-                                'encoding',
-                                'DEFAULT'
+                        if msisdn.startswith("34") or msisdn.startswith("39"):
+                            pass
+                        else:
+                            bar = {
+                                'message': document['json'].get(
+                                    'message',
+                                    'message vide'
+                                    ),
+                                'msisdn': msisdn,
+                                'sender_id': document['json'].get(
+                                    'sender_id',
+                                    'bip'
+                                    ),
+                                'encoding': document['json'].get(
+                                    'encoding',
+                                    'DEFAULT'
+                                    )
+                                }
+                            data = {
+                                key: value for key, value in document.items()
+                                if key != 'json'
+                                }
+                            data['json'] = bar
+                            data['index'] = index
+                            ch.basic_publish(
+                                exchange='sendsms',
+                                routing_key=queue,
+                                body=json.dumps(data),
+                                properties=pika.BasicProperties(
+                                    delivery_mode=2
+                                    )
                                 )
-                            }
-                        data = {
-                            key: value for key, value in document.items()
-                            if key != 'json'
-                            }
-                        data['json'] = bar
-                        data['index'] = index
-                        ch.basic_publish(
-                            exchange='sendsms',
-                            routing_key=queue,
-                            body=json.dumps(data),
-                            properties=pika.BasicProperties(
-                                delivery_mode=2
-                                )
-                            )
                     ch.basic_ack(delivery_tag=method.delivery_tag)
                 else:
                     response = {
@@ -88,7 +91,6 @@ def process(smpp_client, queue):
                     try:
                         # international
                         if document['json'].get("intl"):
-                            LOGS.logger.info("intl")
                             smpp_client.send_sms(
                                 msisdn,
                                 message,
@@ -97,12 +99,15 @@ def process(smpp_client, queue):
                                 sender_id=sender_id
                                 )
                         else:
-                            smpp_client.send_sms(
-                                msisdn,
-                                message,
-                                request_id=request_id,
-                                sender_id=sender_id
-                                )
+                            if msisdn.startswith("34") or msisdn.startswith("39"):
+                                pass
+                            else:
+                                smpp_client.send_sms(
+                                    msisdn,
+                                    message,
+                                    request_id=request_id,
+                                    sender_id=sender_id
+                                    )
                     except Exception as exc:
                         log_msg = (
                             "Erreur survenue lors de l'envoi: {}"
